/*
 * audiocontrol version 0.0.2
 *
 * Author: Fredrik Noring   <noring@lysator.liu.se>
 *
 * Written January 1997
 *
 * (C) 1997 Fredrik Noring
 *
 * This file is subject to the terms and conditions of the GNU General Public
 * License.  See the file COPYING in the main directory of this archive
 * for more details.
 */

#include <time.h>
#include <stdio.h>
#include <fcntl.h>
#include <stdlib.h>
#include <unistd.h>
#include <getopt.h>
#include <sys/ioctl.h>
#include <sys/stat.h>
#include <sys/types.h>
#include <sys/mman.h>

#include "../matrix-0.0.3/matrix.h"

extern char *optarg;

#define NAME "audiocontrol"
#define DEV_MATRIX "/dev/matrix"

void version(void)
{
	printf(NAME" (C) 1997 Fredrik Noring (NoCrew!)\n");
}

void usage(FILE *f)
{
	fprintf(f,
"Usage: "NAME" [OPTION] [FILE]...\n"
"\n"
"  -a,  --attenuation      set output attenuation level (0-15)\n"
"  -r,  --rtatten          set left output attenuation level (0-15)\n"
"  -l,  --ltatten          set right output attenuation level (0-15)\n"
"  -h,  --help             display this help and exit\n"
"  -v,  --verbose          print extra things to please the user\n"
"  -V,  --version          output version information and exit\n"
"\n");
}

int parse_options(int fd, int argc, char *argv[])
{
	int c;
	int verbose = 0;
	
	while (1) {
		int option_index = 0;
		static struct option long_options[] = {
			{"attenuation", 1, 0, 'a'},
			{"ltatten", 1, 0, 'l'},
			{"rtatten", 1, 0, 'r'},
			{"version", 0, 0, 'V'},
			{"verbose", 0, 0, 'v'},
			{"help", 0, 0, 'h'},
			{0, 0, 0, 0}
		};
		c = getopt_long (argc, argv, "hvVa:l:r:",
				 long_options, &option_index);
		if (c == -1)
			break;
		switch (c) {
		case 'h':
			usage(stdout);
			exit(0);
		case 'v':
			fprintf(stderr, "I'm verbose\n");
			verbose = 1;
			break;
		case 'V':
			version();
			exit(0);
		case '?':
			usage(stderr);
			exit(1);
		case 'a':
			if (verbose)
				fprintf(stderr, "setting attenuation to %d\n",
				       atoi(optarg));
			ioctl(fd, MATRIX_SET_LTATTEN, atoi(optarg));
			ioctl(fd, MATRIX_SET_RTATTEN, atoi(optarg));
			break;
		case 'l':
			if (verbose)
			  fprintf(stderr, "setting left attenuation to %d\n",
				  atoi(optarg));
			ioctl(fd, MATRIX_SET_LTATTEN, atoi(optarg));
			break;
		case 'r':
			if (verbose)
			  fprintf(stderr, "setting right attenuation to %d\n",
				  atoi(optarg));
			ioctl(fd, MATRIX_SET_RTATTEN, atoi(optarg));
			break;
		}
	}
	
	return optind;
}

int main(int argc, char *argv[])
{
	int fd;

	/* Open matrix device */
	fd = open(DEV_MATRIX, O_RDWR);
	if (fd == -1) {
		perror("opening "DEV_MATRIX" device");
		exit(1);
	}
	
	parse_options(fd, argc, argv);

	close(fd);
	return 0;
}
